package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERBoolean;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class IssuingDistributionPoint extends ASN1Encodable {
   private DistributionPointName distributionPoint;
   private boolean onlyContainsUserCerts;
   private boolean onlyContainsCACerts;
   private ReasonFlags onlySomeReasons;
   private boolean indirectCRL;
   private boolean onlyContainsAttributeCerts;
   private ASN1Sequence seq;

   public static IssuingDistributionPoint getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static IssuingDistributionPoint getInstance(Object obj) {
      if (obj != null && !(obj instanceof IssuingDistributionPoint)) {
         if (obj instanceof ASN1Sequence) {
            return new IssuingDistributionPoint((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (IssuingDistributionPoint)obj;
      }
   }

   public IssuingDistributionPoint(DistributionPointName distributionPoint, boolean onlyContainsUserCerts, boolean onlyContainsCACerts, ReasonFlags onlySomeReasons, boolean indirectCRL, boolean onlyContainsAttributeCerts) {
      this.distributionPoint = distributionPoint;
      this.indirectCRL = indirectCRL;
      this.onlyContainsAttributeCerts = onlyContainsAttributeCerts;
      this.onlyContainsCACerts = onlyContainsCACerts;
      this.onlyContainsUserCerts = onlyContainsUserCerts;
      this.onlySomeReasons = onlySomeReasons;
      ASN1EncodableVector var7;
      var7 = new ASN1EncodableVector.<init>();
      if (distributionPoint != null) {
         DERTaggedObject var8;
         var8 = new DERTaggedObject.<init>(true, 0, distributionPoint);
         var7.add(var8);
      }

      DERTaggedObject distributionPoint1;
      DERBoolean onlyContainsUserCerts1;
      DERTaggedObject var10001;
      if (!onlyContainsUserCerts) {
         var10001 = distributionPoint1 = new DERTaggedObject;
         onlyContainsUserCerts1 = new DERBoolean.<init>(true);
         var10001.<init>(false, 1, onlyContainsUserCerts1);
         var7.add(distributionPoint1);
      }

      if (!onlyContainsCACerts) {
         var10001 = distributionPoint1 = new DERTaggedObject;
         onlyContainsUserCerts1 = new DERBoolean.<init>(true);
         var10001.<init>(false, 2, onlyContainsUserCerts1);
         var7.add(distributionPoint1);
      }

      if (onlySomeReasons != null) {
         distributionPoint1 = new DERTaggedObject.<init>(false, 3, onlySomeReasons);
         var7.add(distributionPoint1);
      }

      if (!indirectCRL) {
         var10001 = distributionPoint1 = new DERTaggedObject;
         onlyContainsUserCerts1 = new DERBoolean.<init>(true);
         var10001.<init>(false, 4, onlyContainsUserCerts1);
         var7.add(distributionPoint1);
      }

      if (!onlyContainsAttributeCerts) {
         var10001 = distributionPoint1 = new DERTaggedObject;
         onlyContainsUserCerts1 = new DERBoolean.<init>(true);
         var10001.<init>(false, 5, onlyContainsUserCerts1);
         var7.add(distributionPoint1);
      }

      IssuingDistributionPoint var10000 = this;
      DERSequence var9;
      var9 = new DERSequence.<init>(var7);
      var10000.seq = var9;
   }

   public IssuingDistributionPoint(ASN1Sequence seq) {
      this.seq = seq;

      for(int var2 = 0; var2 != seq.size(); ++var2) {
         ASN1TaggedObject var3;
         switch ((var3 = ASN1TaggedObject.getInstance(seq.getObjectAt(var2))).getTagNo()) {
            case 0:
               this.distributionPoint = DistributionPointName.getInstance(var3, true);
               break;
            case 1:
               this.onlyContainsUserCerts = DERBoolean.getInstance(var3, false).isTrue();
               break;
            case 2:
               this.onlyContainsCACerts = DERBoolean.getInstance(var3, false).isTrue();
               break;
            case 3:
               this.onlySomeReasons = new ReasonFlags(DERBitString.getInstance(var3, false));
               break;
            case 4:
               this.indirectCRL = DERBoolean.getInstance(var3, false).isTrue();
               break;
            case 5:
               this.onlyContainsAttributeCerts = DERBoolean.getInstance(var3, false).isTrue();
               break;
            default:
               throw new IllegalArgumentException("unknown tag in IssuingDistributionPoint");
         }
      }

   }

   private void appendObject(StringBuffer buf, String sep, String name, String value) {
      buf.append("    ");
      buf.append(name);
      buf.append(":");
      buf.append(sep);
      buf.append("    ");
      buf.append("    ");
      buf.append(value);
      buf.append(sep);
   }

   private String booleanToString(boolean value) {
      return value ? "true" : "false";
   }

   public boolean onlyContainsUserCerts() {
      return this.onlyContainsUserCerts;
   }

   public boolean onlyContainsCACerts() {
      return this.onlyContainsCACerts;
   }

   public boolean isIndirectCRL() {
      return this.indirectCRL;
   }

   public boolean onlyContainsAttributeCerts() {
      return this.onlyContainsAttributeCerts;
   }

   public DistributionPointName getDistributionPoint() {
      return this.distributionPoint;
   }

   public ReasonFlags getOnlySomeReasons() {
      return this.onlySomeReasons;
   }

   public DERObject toASN1Object() {
      return this.seq;
   }

   public String toString() {
      String var1 = System.getProperty("line.separator");
      StringBuffer var2;
      StringBuffer var10001 = var2 = new StringBuffer;
      var10001.<init>();
      var10001.append("IssuingDistributionPoint: [");
      var10001.append(var1);
      DistributionPointName var3;
      String var5;
      if ((var3 = this.distributionPoint) != null) {
         var5 = var3.toString();
         this.appendObject(var2, var1, "distributionPoint", var5);
      }

      boolean var6;
      if (var6 = this.onlyContainsUserCerts) {
         var5 = this.booleanToString(var6);
         this.appendObject(var2, var1, "onlyContainsUserCerts", var5);
      }

      if (var6 = this.onlyContainsCACerts) {
         var5 = this.booleanToString(var6);
         this.appendObject(var2, var1, "onlyContainsCACerts", var5);
      }

      ReasonFlags var7;
      if ((var7 = this.onlySomeReasons) != null) {
         var5 = var7.toString();
         this.appendObject(var2, var1, "onlySomeReasons", var5);
      }

      if (var6 = this.onlyContainsAttributeCerts) {
         var5 = this.booleanToString(var6);
         this.appendObject(var2, var1, "onlyContainsAttributeCerts", var5);
      }

      if (var6 = this.indirectCRL) {
         IssuingDistributionPoint var10000 = this;
         String var4 = this.booleanToString(var6);
         var10000.appendObject(var2, var1, "indirectCRL", var4);
      }

      var2.append("]");
      var2.append(var1);
      return var2.toString();
   }
}
